@@ -30,10 +30,10 @@ NULL
 #' @section Objects from the class:
 #' Objects can be created by calls of the form `set_RLum("RLum.Data.Image", ...)`.
 #'
-#' @section Class version: 0.5.0
+#' @section Class version: 0.5.1
 #'
 #' @author
-#' Sebastian Kreutzer, Geography & Earth Sciences, Aberystwyth University (United Kingdom)
+#' Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)
 #'
 #' @seealso [RLum-class], [RLum.Data-class], [plot_RLum], [read_SPE2R], [read_TIFF2R]
 #'
@@ -187,7 +187,7 @@ setMethod("show",
             cat("\n\t .. .. pixel per frame:", dim[1]*dim[2])
             cat("\n\t .. .. x dimension [px]:", dim[1])
             cat("\n\t .. .. y dimension [px]:", dim[2])
-            cat("\n\t .. .. full pixel value range:", paste(range(object@data), collapse=":"))
+            cat("\n\t .. .. full pixel value range:", paste(format(range(object@data), scientific = TRUE, digits = 2), collapse=" : "))
             cat("\n\t additional info elements:", length(object@info))
             #cat("\n\t\t >> names:", names(object@info))
           }
@@ -324,7 +324,7 @@ setMethod("get_RLum",
 
             ##if missing info.object just show the curve values
             if(!missing(info.object)){
-              if(class(info.object) != "character")
+              if(!inherits(info.object, "character"))
                 stop("[get_RLum] 'info.object' has to be a character!", call. = FALSE)
 
               if(info.object %in% names(object@info)){
