@@ -1,41 +1,42 @@
-#' Nonlinear Least Squares Fit for LM-OSL curves
+#' @title Nonlinear Least Squares Fit for LM-OSL curves
 #'
-#' The function determines weighted nonlinear least-squares estimates of the
+#' @description The function determines weighted nonlinear least-squares estimates of the
 #' component parameters of an LM-OSL curve (Bulur 1996) for a given number of
 #' components and returns various component parameters. The fitting procedure
 #' uses the function [nls] with the `port` algorithm.
 #'
+#' @details
 #' **Fitting function**
 #'
 #' The function for the fitting has the general
-#' form: 
-#' 
-#' \deqn{y = (exp(0.5)*Im_1*x/xm_1)*exp(-x^2/(2*xm_1^2)) + ,\ldots, + exp(0.5)*Im_i*x/xm_i)*exp(-x^2/(2*xm_i^2))} 
-#' 
+#' form:
+#'
+#' \deqn{y = (exp(0.5)*Im_1*x/xm_1)*exp(-x^2/(2*xm_1^2)) + ,\ldots, + exp(0.5)*Im_i*x/xm_i)*exp(-x^2/(2*xm_i^2))}
+#'
 #' where \eqn{1 < i < 8}
-#' 
+#'
 #' This function and the equations for the conversion to b (detrapping probability)
 #' and n0 (proportional to initially trapped charge) have been taken from Kitis
-#' et al. (2008): 
-#' 
-#' \deqn{xm_i=\sqrt{max(t)/b_i}} 
+#' et al. (2008):
+#'
+#' \deqn{xm_i=\sqrt{max(t)/b_i}}
 #' \deqn{Im_i=exp(-0.5)n0/xm_i}
-#' 
+#'
 #' **Background subtraction**
 #'
 #' Three methods for background subtraction
 #' are provided for a given background signal (`values.bg`).
-#' 
-#' - `polynomial`: default method. A polynomial function is fitted using [glm] 
+#'
+#' - `polynomial`: default method. A polynomial function is fitted using [glm]
 #' and the resulting function is used for background subtraction:
 #' \deqn{y = a*x^4 + b*x^3 + c*x^2 + d*x + e}
-#' 
-#' - `linear`: a linear function is fitted using [glm] and the resulting function 
+#'
+#' - `linear`: a linear function is fitted using [glm] and the resulting function
 #' is used for background subtraction:
 #' \deqn{y = a*x + b}
-#'  
+#'
 #' - `channel`: the measured
-#' background signal is subtracted channelwise from the measured signal.
+#' background signal is subtracted channel wise from the measured signal.
 #'
 #'
 #' **Start values**
@@ -44,130 +45,130 @@
 #' point and the fitting procedure may mainly fail due to ill chosen start
 #' parameters. Here, three options are provided:
 #'
-#' **(a)** 
+#' **(a)**
 #' If no start values (`start_values`) are provided by the user, a cheap guess is made
 #' by using the detrapping values found by Jain et al. (2003) for quartz for a
 #' maximum of 7 components. Based on these values, the pseudo start parameters
-#' xm and Im are recalculated for the given data set. In all cases, the fitting
+#' `xm` and `Im` are recalculated for the given data set. In all cases, the fitting
 #' starts with the ultra-fast component and (depending on `n.components`)
 #' steps through the following values. If no fit could be achieved, an error
 #' plot (for `plot = TRUE`) with the pseudo curve (based on the
 #' pseudo start parameters) is provided. This may give the opportunity to
 #' identify appropriate start parameters visually.
 #'
-#' **(b)** 
+#' **(b)**
 #' If start values are provided, the function works like a simple [nls]
 #' fitting approach.
 #'
-#' **(c)** 
+#' **(c)**
 #' If no start parameters are provided and
-#' the option `fit.advanced = TRUE` is chosen, an advanced start paramter
-#' estimation is applied using a stochastical attempt. Therefore, the
+#' the option `fit.advanced = TRUE` is chosen, an advanced start parameter
+#' estimation is applied using a stochastic attempt. Therefore, the
 #' recalculated start parameters **(a)** are used to construct a normal
 #' distribution. The start parameters are then sampled randomly from this
 #' distribution. A maximum of 100 attempts will be made. **Note:** This
-#' process may be time consuming. 
+#' process may be time consuming.
 #'
 #' **Goodness of fit**
 #'
-#' The goodness of the fit is given by a pseudoR^2 value (pseudo coefficient of
+#' The goodness of the fit is given by a pseudo-R^2 value (pseudo coefficient of
 #' determination). According to Lave (1970), the value is calculated as:
-#' 
-#' \deqn{pseudoR^2 = 1 - RSS/TSS} 
-#' 
+#'
+#' \deqn{pseudoR^2 = 1 - RSS/TSS}
+#'
 #' where \eqn{RSS = Residual~Sum~of~Squares}
 #' and \eqn{TSS = Total~Sum~of~Squares}
 #'
 #' **Error of fitted component parameters**
 #'
 #' The 1-sigma error for the components is calculated using
-#' the function [confint]. Due to considerable calculation time, this
-#' option is deactived by default. In addition, the error for the components
+#' the function [stats::confint]. Due to considerable calculation time, this
+#' option is deactivated by default. In addition, the error for the components
 #' can be estimated by using internal R functions like [summary]. See the
 #' [nls] help page for more information.
-#' 
+#'
 #' *For more details on the nonlinear regression in R, see Ritz & Streibig (2008).*
 #'
-#' @param values [RLum.Data.Curve-class] or [data.frame] (**required**): 
+#' @param values [RLum.Data.Curve-class] or [data.frame] (**required**):
 #' x,y data of measured values (time and counts). See examples.
 #'
-#' @param values.bg [RLum.Data.Curve-class] or [data.frame] (*optional*): 
+#' @param values.bg [RLum.Data.Curve-class] or [data.frame] (*optional*):
 #' x,y data of measured values (time and counts) for background subtraction.
 #'
-#' @param n.components [integer] (*with default*): 
-#' fixed number of components that are to be recognised during fitting 
+#' @param n.components [integer] (*with default*):
+#' fixed number of components that are to be recognised during fitting
 #' (min = 1, max = 7).
 #'
-#' @param start_values [data.frame] (*optional*): 
-#' start parameters for lm and xm data for the fit. If no start values are given, 
+#' @param start_values [data.frame] (*optional*):
+#' start parameters for `lm` and `xm` data for the fit. If no start values are given,
 #' an automatic start value estimation is attempted (see details).
 #'
-#' @param input.dataType [character] (*with default*): 
-#' alter the plot output depending on the input data: "LM" or "pLM" (pseudo-LM). 
+#' @param input.dataType [character] (*with default*):
+#' alter the plot output depending on the input data: `"LM"` or `"pLM"` (pseudo-LM).
 #' See: [CW2pLM]
 #'
-#' @param fit.method [character] (*with default*): 
+#' @param fit.method [character] (*with default*):
 #' select fit method, allowed values: `'port'` and `'LM'`. `'port'` uses the 'port'
-#' routine usint the funtion [nls] `'LM'` utilises the function `nlsLM` from 
+#' routine from the function [nls] `'LM'` utilises the function `nlsLM` from
 #' the package `minpack.lm` and with that the Levenberg-Marquardt algorithm.
 #'
-#' @param sample_code [character] (*optional*): 
+#' @param sample_code [character] (*optional*):
 #' sample code used for the plot and the optional output table (mtext).
 #'
 #' @param sample_ID [character] (*optional*):
 #' additional identifier used as column header for the table output.
 #'
-#' @param LED.power [numeric] (*with default*): 
-#' LED power (max.) used forintensity ramping in mW/cm^2.
-#' **Note:** This value is used for the calculation of the absolute 
+#' @param LED.power [numeric] (*with default*):
+#' LED power (max.) used for intensity ramping in mW/cm^2.
+#' **Note:** This value is used for the calculation of the absolute
 #' photoionisation cross section.
 #'
-#' @param LED.wavelength [numeric] (*with default*): 
-#' LED wavelength in nm used for stimulation. 
-#' **Note:** This value is used for the calculation of the absolute 
+#' @param LED.wavelength [numeric] (*with default*):
+#' LED wavelength in nm used for stimulation.
+#' **Note:** This value is used for the calculation of the absolute
 #' photoionisation cross section.
 #'
-#' @param fit.trace [logical] (*with default*): 
+#' @param fit.trace [logical] (*with default*):
 #' traces the fitting process on the terminal.
 #'
-#' @param fit.advanced [logical] (*with default*): 
-#' enables advanced fitting attempt for automatic start parameter recognition. 
-#' Works only if no start parameters are provided. 
+#' @param fit.advanced [logical] (*with default*):
+#' enables advanced fitting attempt for automatic start parameter recognition.
+#' Works only if no start parameters are provided.
 #' **Note:** It may take a while and it is not compatible with `fit.method = "LM"`.
 #'
-#' @param fit.calcError [logical] (*with default*): 
-#' calculate 1-sigma error range of components using [confint].
+#' @param fit.calcError [logical] (*with default*):
+#' calculate 1-sigma error range of components using [stats::confint].
 #'
-#' @param bg.subtraction [character] (*with default*): 
+#' @param bg.subtraction [character] (*with default*):
 #' specifies method for background subtraction (`polynomial`, `linear`, `channel`,
 #' see Details). **Note:** requires input for `values.bg`.
 #'
 #' @param verbose [logical] (*with default*):
 #'  terminal output with fitting results.
 #'
-#' @param plot [logical] (*with default*): 
+#' @param plot [logical] (*with default*):
 #' returns a plot of the fitted curves.
 #'
-#' @param plot.BG [logical] (*with default*): 
-#' returns a plot of the background values with the fit used for the 
+#' @param plot.BG [logical] (*with default*):
+#' returns a plot of the background values with the fit used for the
 #' background subtraction.
 #'
 #' @param ... Further arguments that may be passed to the plot output, e.g.
 #' `xlab`, `xlab`, `main`, `log`.
 #'
 #' @return
-#' Various types of plots are returned. For details see above. Furthermore an 
+#' Various types of plots are returned. For details see above. Furthermore an
 #' `RLum.Results` object is returned with the following structure:
 #'
 #' **`@data:`**
-#' 
+#'
 #' `.. $data` : [data.frame] with fitting results\cr
 #' `.. $fit` : nls ([nls] object)\cr
+#' `.. $component_matrix` : [matrix] with numerical xy-values of the single fitted components with the resolution of the input data
 #' `.. $component.contribution.matrix` : [list] component distribution matrix
-#' 
 #'
 #' **`info:`**
-#' 
+#'
 #' `.. $call` : [call] the original function call
 #'
 #' Matrix structure for the distribution matrix:
@@ -178,23 +179,23 @@
 #' the relative component contribution for each time interval including the row
 #' sum for this values.
 #'
-#' @note 
+#' @note
 #' The pseudo-R^2 may not be the best parameter to describe the goodness
 #' of the fit. The trade off between the `n.components` and the pseudo-R^2
-#' value currently remains unconsidered. 
+#' value currently remains unconsidered.
 #'
 #' The function **does not** ensure that the fitting procedure has reached a
 #' global minimum rather than a local minimum! In any case of doubt, the use of
 #' manual start values is highly recommended.
 #'
-#' @section Function version: 0.3.2
+#' @section Function version: 0.3.4
 #'
-#' @author 
-#' Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne (France)
+#' @author
+#' Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)
 #'
 #' @seealso [fit_CWCurve], [plot], [nls], [minpack.lm::nlsLM], [get_RLum]
 #'
-#' @references 
+#' @references
 #' Bulur, E., 1996. An Alternative Technique For Optically
 #' Stimulated Luminescence (OSL) Experiment. Radiation Measurements, 26, 5,
 #' 701-709.
@@ -265,20 +266,17 @@ fit_LMCurve<- function(
 
   ##(1) data.frame or RLum.Data.Curve object?
   if(is(values, "data.frame") == FALSE & is(values, "RLum.Data.Curve") == FALSE){
-
-    stop("[fit_LMCurve()] 'values' object has to be of type
-         'data.frame' or 'RLum.Data.Curve'!")
+    stop("[fit_LMCurve()] 'values' has to be of type 'data.frame' or 'RLum.Data.Curve'!", call. = FALSE)
 
   }else{
 
     if(is(values, "RLum.Data.Curve") == TRUE && (
       values@recordType!="RBR" & values@recordType!="LM-OSL")){
-
       stop("[fit_LMCurve()] recordType should be 'RBR' or 'LM-OSL'!
-           Consider as(object,'data.frame') if you had used the pseudo transformation functions.")
-
-    }else if(is(values, "RLum.Data.Curve") == TRUE){
+           Consider using as(object,'data.frame') if you had used a pseudo transformation function.",
+           call. = FALSE)
 
+    }else if(is(values, "RLum.Data.Curve")){
       values <- as(values,"data.frame")
 
     }
@@ -286,20 +284,16 @@ fit_LMCurve<- function(
 
   ##(2) data.frame or RLum.Data.Curve object?
   if(missing(values.bg)==FALSE){
-
     if(is(values.bg, "data.frame") == FALSE & is(values.bg,
                                                  "RLum.Data.Curve") == FALSE){
-
-      stop("[fit_LMCurve()] 'values.bg' object has to be of type 'data.frame' or 'RLum.Data.Curve'!")
+      stop("[fit_LMCurve()] 'values.bg' object has to be of type 'data.frame' or 'RLum.Data.Curve'!",
+           call. = FALSE)
 
     }else{
-
       if(is(values, "RLum.Data.Curve") == TRUE && values@recordType!="RBR"){
+        stop("[fit_LMCurve()] recordType should be 'RBR'!", call. = FALSE)
 
-        stop("[fit_LMCurve()] recordType should be 'RBR'!")
-
-      }else if(is(values.bg, "RLum.Data.Curve") == TRUE){
-
+      }else if(is(values.bg, "RLum.Data.Curve")){
         values.bg <- as(values.bg,"data.frame")
 
       }
@@ -351,24 +345,24 @@ fit_LMCurve<- function(
 
   fun       <- if("fun" %in% names(extraArgs)) {extraArgs$fun} else {FALSE}
 
+  # layout safety settings
+  par.default <- par()[c("mfrow", "cex", "mar", "omi", "oma")]
+  on.exit(par(par.default))
 
   ##============================================================================##
   ##  BACKGROUND SUBTRACTION
   ##============================================================================##
-
-  #   ##perform background subtraction if background LM measurment exists
-
   if(missing(values.bg)==FALSE){
-
     #set graphical parameters
-    par.default <- par(mfrow=c(1,1), cex=1.5*cex)
+    par(mfrow=c(1,1), cex=1.5*cex)
 
     ##check if length of bg and signal is consistent
-    if(length(values[,2])!=length(values.bg[,2])){stop("[fit_LMCurve] Length of values and values.bg differs!")}
+    if(length(values[,2])!=length(values.bg[,2]))
+      stop("[fit_LMCurve] Length of values and values.bg differs!", call. = FALSE)
 
     if(bg.subtraction=="polynomial"){
 
-      #fit polynom function to background
+      #fit polynomial function to background
       glm.fit<-glm(values.bg[,2] ~ values.bg[,1]+I(values.bg[,1]^2)+I(values.bg[,1]^3))
       glm.coef<-coef(glm.fit)
 
@@ -428,11 +422,10 @@ fit_LMCurve<- function(
         mtext(side=3,sample_code,cex=.8*cex)
       }
 
-    }else{stop("Error: Invalid method for background subtraction")}
+    } else {
+      stop("[fit_LMCurve()] Invalid method for background subtraction", call. = FALSE)
+    }
 
-    ##reset par values
-    par(par.default)
-    rm(par.default)
   }
 
 
@@ -453,7 +446,7 @@ fit_LMCurve<- function(
   ##------------------------------------------------------------------------##
 
   ##set formula elements for fitting functions
-  ## the upper two funtions should be removed ... but chances are needed ... TODO
+  ## the upper two functions should be removed ... but chances are needed ... TODO
   ##////equation used for fitting////(start)
   fit.formula <- function(n.components){
 
@@ -469,7 +462,7 @@ fit_LMCurve<- function(
   ##automatic start parameter estimation
 
   ##set fit function
-  fit.function<-fit.equation(Im.i=1:n.components,xm.i=1:n.components)
+  fit.function <- fit.equation(Im.i = 1:n.components, xm.i = 1:n.components)
 
   if(missing(start_values)){
 
@@ -576,8 +569,7 @@ fit_LMCurve<- function(
           ), silent = TRUE)
 
         }else{
-
-          stop("[fit_LMCurve()] unknow method for 'fit.method'")
+          stop("[fit_LMCurve()] unknow method for 'fit.method'", call. = FALSE)
 
         }
 
@@ -665,18 +657,25 @@ fit_LMCurve<- function(
 
     ##CALCULATE 1- sigma CONFIDENCE INTERVAL
     ##------------------------------------------------------------------------##
-    b.error<-rep(NA, n.components)
-    n0.error<-rep(NA, n.components)
+    b.error <- rep(NA, n.components)
+    n0.error <- rep(NA, n.components)
 
-    if(fit.calcError==TRUE){
+    if(fit.calcError){
       ##option for confidence interval
-      values.confint<-confint(fit, level=0.68)
-      Im.confint<-values.confint[1:(length(values.confint[,1])/2),]
-      xm.confint<-values.confint[((length(values.confint[,1])/2)+1):length(values.confint[,1]),]
+      values.confint <- try(confint(fit, level = 0.68), silent = TRUE)
 
-      ##error calculation
-      b.error<-as.vector(abs((max(values[,1])/xm.confint[,1]^2)-(max(values[,1])/xm.confint[,2]^2)))
-      n0.error<-as.vector(abs(((Im.confint[,1]/exp(-0.5))*xm.confint[,1]) - ((Im.confint[,2]/exp(-0.5))*xm.confint[,2])))
+      if(!inherits(values.confint, "try-error")) {
+        Im.confint <- values.confint[1:(length(values.confint[, 1]) / 2), ]
+        xm.confint <- values.confint[((length(values.confint[,1])/2)+1):length(values.confint[,1]),]
+
+        ##error calculation
+        b.error < -as.vector(abs((max(values[,1])/xm.confint[,1]^2)-(max(values[,1])/xm.confint[,2]^2)))
+        n0.error <- as.vector(abs(((Im.confint[,1]/exp(-0.5))*xm.confint[,1]) - ((Im.confint[,2]/exp(-0.5))*xm.confint[,2])))
+
+      } else {
+        warning("[fit_LMCurve()] The computation of the parameter confidence intervals failed. Please try to run stats::confint() manually on the $fit output object!", call. = FALSE)
+
+      }
     }
     ##------------------------------------------------------------------------##
 
@@ -774,7 +773,6 @@ fit_LMCurve<- function(
     component.contribution.matrix.area <- sapply(
       seq(3,ncol(component.contribution.matrix),by=2),
       function(x){
-
         matrixStats::rowDiffs(cbind(rev(component.contribution.matrix[,(x+1)]),
                        component.contribution.matrix[,x]))
 
@@ -827,7 +825,6 @@ fit_LMCurve<- function(
 
     ##write output table if values exists
     if (exists("fit")){
-
       ##set data.frame for a max value of 7 components
       output.table <- data.frame(NA,NA,NA,NA,NA,NA,NA,NA,
                                  NA,NA,NA,NA,NA,NA,NA,NA,
@@ -884,18 +881,34 @@ fit_LMCurve<- function(
 
       ##----------------------------------------------------------------------------##
     }#endif::exists fit
-  }else{
 
+  }else{
     output.table <- NA
     component.contribution.matrix <- NA
-    writeLines("[fit_LMCurve] Fitting Error: Plot without fit produced!")
+    message("[fit_LMCurve] Fitting Error: Plot without fit produced!")
 
   }
-  ##============================================================================##
-  ##  PLOTTING
-  ##============================================================================##
-  if(plot){
 
+  # Calculate component curves ----------------------------------------------
+  component_matrix <- NA
+  if(!inherits(fit,"try-error")){
+    component_matrix <- matrix(NA, nrow = nrow(values), ncol = 2 + length(Im))
+    colnames(component_matrix) <- c("TIME", "SUM", paste("COMP_", 1:length(Im)))
+    component_matrix[, 1] <- values[, 1]
+    component_matrix[, 2] <- eval(fit.function)
+
+    ## add single components
+    for(i in 1:length(Im)){
+      component_matrix[, 2 + i] <-
+        exp(0.5) * Im[i] * values[, 1] /
+        xm[i] * exp(-values[, 1] ^ 2 / (2 * xm[i] ^ 2))
+
+    }
+
+  }
+
+  # Plotting ----------------------------------------------------------------
+  if(plot){
     ##cheat the R check routine
     x <- NULL; rm(x)
 
@@ -907,17 +920,13 @@ fit_LMCurve<- function(
       warning("[fit_LMCurve()] x-axis limitation change to avoid 0 values for log-scale!", call. = FALSE)
       xlim <- c(2^0.5/2 * max(values[,1])/length(values[,1]), xlim[2])
 
-
     }
 
-
     ##set plot frame
-    par.default <- par(no.readonly = TRUE)
+    layout(matrix(c(1,2,3),3,1, byrow=TRUE),c(1.6,1,1), c(1,0.3,0.4),TRUE)
+    par(oma = c(1,1,1,1), mar = c(0,4,3,0), cex=cex)
 
-    layout(matrix(c(1,2,3),3,1,byrow=TRUE),c(1.6,1,1), c(1,0.3,0.4),TRUE)
-    par(oma=c(1,1,1,1),mar=c(0,4,3,0), cex=cex)
-
-    ##==uppper plot==##
+    ##==upper plot==##
     ##open plot area
     plot(
       NA,
@@ -1027,13 +1036,10 @@ fit_LMCurve<- function(
       }
       rm(stepping)
 
-      ##reset par
-      par(par.default)
-      rm(par.default)
       ##------------------------------------------------------------------------##
     }#end if try-error for fit
 
-    if(fun==TRUE){sTeve()}
+    if(fun){sTeve()}
   }
   ##-----------------------------------------------------------------------------
   ##remove objects
@@ -1047,6 +1053,7 @@ fit_LMCurve<- function(
     data = list(
       data = output.table,
       fit = fit,
+      component_matrix = component_matrix,
       component.contribution.matrix = list(component.contribution.matrix)
     ),
     info = list(call = sys.call())
