@@ -1,7 +1,7 @@
 #' Plot filter combinations along with the (optional) net transmission window
 #'
 #' The function allows to plot transmission windows for different filters. Missing data for specific
-#' wavelenghts are automatically interpolated for the given filter data using the function [approx].
+#' wavelengths are automatically interpolated for the given filter data using the function [approx].
 #' With that a standardised output is reached and a net transmission window can be shown.
 #'
 #' **Calculations**
@@ -14,7 +14,7 @@
 #'
 #' **Optical density**
 #'
-#' \deqn{OD = -log(T)}
+#' \deqn{OD = -log10(T)}
 #'
 #' **Total optical density**
 #'
@@ -27,11 +27,11 @@
 #' *CASE 1*
 #'
 #' The function expects that all filter values are either of type `matrix` or `data.frame`
-#' with two columns. The first columens contains the wavelength, the second the relative transmission
+#' with two columns. The first columns contains the wavelength, the second the relative transmission
 #' (but not in percentage, i.e. the maximum transmission can be only become 1).
 #'
 #' In this case only the transmission window is show as provided. Changes in filter thickness and
-#' relection factor are not considered.
+#' reflection factor are not considered.
 #'
 #' *CASE 2*
 #'
@@ -65,7 +65,7 @@
 #' `net_transmission.col` \tab `col` \tab colour of net transmission window polygon \cr
 #' `net_transmission.col_lines` \tab `col` \tab colour of net transmission window polygon lines \cr
 #' `net_transmission.density` \tab  `numeric` \tab specify line density in the transmission polygon \cr
-#' `grid` \tab `list` \tab full list of arguments that can be passd to the function [graphics::grid]
+#' `grid` \tab `list` \tab full list of arguments that can be passed to the function [graphics::grid]
 #' }
 #'
 #' For further modifications standard additional R plot functions are recommend, e.g., the legend
@@ -91,7 +91,7 @@
 #' enables or disables the plot output
 #'
 #' @param ... further arguments that can be passed to control the plot output.
-#' Suppored are `main`, `xlab`, `ylab`, `xlim`, `ylim`, `type`, `lty`, `lwd`.
+#' Supported are `main`, `xlab`, `ylab`, `xlim`, `ylim`, `type`, `lty`, `lwd`.
 #' For non common plotting parameters see the details section.
 #'
 #' @return Returns an S4 object of type [RLum.Results-class].
@@ -112,9 +112,9 @@
 #' `call` \tab [call] \tab the original function call
 #' }
 #'
-#' @section Function version: 0.3.1
+#' @section Function version: 0.3.2
 #'
-#' @author Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montagine (France)
+#' @author Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)
 #'
 #' @seealso [RLum.Results-class], [approx]
 #'
@@ -247,7 +247,7 @@ plot_FilterCombinations <- function(
   ##add optical density to filter matrix
 
   ##calculate OD
-  OD <- -log(filter_matrix)
+  OD <- -log10(filter_matrix)
 
   ##calculate  total OD
   OD_total <- cbind(wavelength_range, matrixStats::rowSums2(OD))
@@ -410,7 +410,7 @@ plot_FilterCombinations <- function(
 
 
   # Produce output object -----------------------------------------------------------------------
-  return(set_RLum(
+  invisible(set_RLum(
     class = "RLum.Results",
     data = list(
       net_transmission_window = net_transmission_window,
