@@ -1,10 +1,11 @@
-#' Export Risoe.BINfileData into Risoe BIN-file
+#' @title Export Risoe.BINfileData into Risø BIN/BINX-file
 #'
-#' Exports a Risoe.BINfileData object in a *.bin or *.binx file that can be
-#' opened by the Analyst software or other Risoe software.
+#' @description Exports a `Risoe.BINfileData` object in a `*.bin` or `*.binx` file that can be
+#' opened by the Analyst software or other Risø software.
 #'
+#' @details
 #' The structure of the exported binary data follows the data structure
-#' published in the Appendices of the Analyst manual p. 42.
+#' published in the Appendices of the *Analyst* manual p. 42.
 #'
 #' If
 #' `LTYPE`, `DTYPE` and `LIGHTSOURCE` are not of type
@@ -44,20 +45,20 @@
 #'
 #' The validity of the file path is not further checked. BIN-file conversions
 #' using the argument `version` may be a lossy conversion, depending on the
-#' chosen input andoutput data (e.g., conversion from version 08 to 07 to 06 to 04 or 03).
+#' chosen input and output data (e.g., conversion from version 08 to 07 to 06 to 05 to 04 or 03).
 #'
 #' **Warning**
 #'
 #' Although the coding was done carefully it seems that the BIN/BINX-files
-#' produced by Risoe DA 15/20 TL/OSL readers slightly differ on the byte level.
+#' produced by Risø DA 15/20 TL/OSL readers slightly differ on the byte level.
 #' No obvious differences are observed in the METADATA, however, the
 #' BIN/BINX-file may not fully compatible, at least not similar to the once
-#' directly produced by the Risoe readers!
+#' directly produced by the Risø readers!
 #'
-#' @section Function version: 0.4.4
+#' @section Function version: 0.5.2
 #'
 #' @author
-#' Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne (France)
+#' Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)
 #'
 #' @note
 #' ROI definitions (introduced in BIN-file version 8) are not supported!
@@ -66,17 +67,22 @@
 #' @seealso [read_BIN2R], [Risoe.BINfileData-class], [writeBin]
 #'
 #' @references
-#' DTU Nutech, 2016. The Squence Editor, Users Manual, February, 2016.
-#' [http://www.nutech.dtu.dk/english/products-and-services/radiation-instruments/tl_osl_reader/manuals]()
+#' DTU Nutech, 2016. The Sequence Editor, Users Manual, February, 2016.
+#' [https://www.fysik.dtu.dk]()
 #'
 #' @keywords IO
 #'
 #' @examples
+#' ##load exampled dataset
+#' file <- system.file("extdata/BINfile_V8.binx", package = "Luminescence")
+#' temp <- read_BIN2R(file)
 #'
-#' ##uncomment for usage
+#' ##create temporary file path
+#' ##(for usage replace by own path)
+#' temp_file <- tempfile(pattern = "output", fileext = ".binx")
 #'
-#' ##data(ExampleData.BINfileData, envir = environment())
-#' ##write_R2BIN(CWOSL.SAR.Data, file="[your path]/output.bin")
+#' ##export to temporary file path
+#' write_R2BIN(temp, file = temp_file)
 #'
 #' @md
 #' @export
@@ -91,7 +97,7 @@ write_R2BIN <- function(
   # Config ------------------------------------------------------------------
 
   ##set supported BIN format version
-  VERSION.supported <- as.raw(c(3, 4, 6, 7, 8))
+  VERSION.supported <- as.raw(c(3, 4, 5, 6, 7, 8))
 
   # Check integrity ---------------------------------------------------------
 
@@ -101,7 +107,7 @@ write_R2BIN <- function(
 
   }
 
-  ##check if it fullfills the latest definition ...
+  ##check if it fulfils the latest definition ...
   if(ncol(object@METADATA) != ncol(set_Risoe.BINfileData()@METADATA)){
     stop("[write_R2BIN()] The number of columns in your slot 'METADATA' does not fit to the latest definition. What you are probably trying to do is to export a Risoe.BINfileData object you generated by your own or you imported with an old package version some time ago. Please re-import the BIN-file using the function read_BIN2R().", call. = FALSE)
 
@@ -113,9 +119,7 @@ write_R2BIN <- function(
 
   }
 
-
   # Check Risoe.BINfileData Struture ----------------------------------------
-
   ##check wether the BIN-file DATA slot contains more than 9999 records; needs to be run all the time
   temp_check <- vapply(object@DATA, function(x){
     if(length(x) > 9999){
@@ -135,7 +139,6 @@ write_R2BIN <- function(
     ##BIN data to reduce amount of data if the BIN-file is too long
     object@DATA <- lapply(object@DATA, function(x){
       if(length(x) > 9999){
-
         ##we want to have a minimum binning (smallest number possible)
         bin_width <- ceiling(length(x)/9999)
 
@@ -148,7 +151,6 @@ write_R2BIN <- function(
         ##create matrix and return
         colSums(matrix(x, nrow = bin_width))
 
-
       }else{
         x
 
@@ -200,30 +202,25 @@ write_R2BIN <- function(
 
     ##Furthermore, entries length needed to be recalculated
     if(version.original != version){
-
       ##stepping decision
-      header.stepping <- switch(as.character(version),
-                                "08" = 507,
-                                "07" = 447,
-                                "06" = 447,
-                                "04" = 272,
-                                "03" = 272)
-
-      object@METADATA[,"LENGTH"] <- sapply(1:nrow(object@METADATA), function(x){
+      header.stepping <- switch(
+        EXPR = as.character(version),
+        "08" = 507,
+        "07" = 447,
+        "06" = 447,
+        "05" = 423,
+        "04" = 272,
+        "03" = 272)
 
+      object@METADATA[,"LENGTH"] <- vapply(1:nrow(object@METADATA), function(x){
         header.stepping + 4 * object@METADATA[x,"NPOINTS"]
 
-      })
+      }, numeric(1))
 
-      object@METADATA[,"PREVIOUS"] <- sapply(1:nrow(object@METADATA), function(x){
+      object@METADATA[,"PREVIOUS"] <- vapply(1:nrow(object@METADATA), function(x){
+        if(x == 1) 0 else header.stepping + 4 * object@METADATA[x-1,"NPOINTS"]
 
-        if(x == 1){
-          0
-        }else{
-          header.stepping + 4 * object@METADATA[x-1,"NPOINTS"]
-        }
-
-      })
+      }, numeric(1))
 
     }
 
@@ -231,7 +228,7 @@ write_R2BIN <- function(
 
   ##check whether this file can be exported without problems due to the latest specifications
   if(ncol(object@METADATA) != 80){
-    stop("[write_R2BIN()] Your Risoe.BINfileData object seems not to be compatible with the latest specification of this S4-class object. You are probably trying to export a Risoe.BINfileData from your workspace you produced manually or with an old version.")
+    stop("[write_R2BIN()] Your Risoe.BINfileData object seems not to be compatible with the latest specification of this S4-class object. You are probably trying to export a Risoe.BINfileData from your workspace you produced manually or with an old version.", call. = FALSE)
 
   }
 
@@ -248,14 +245,12 @@ write_R2BIN <- function(
   }
 
   ##CHECK file name for version == 06 it has to be *.binx and correct for it
-  if(version == 06 | version == 07 | version == 08){
-
+  if(version == 05 | version == 06 | version == 07 | version == 08){
     ##grep file ending
     temp.file.name <- unlist(strsplit(file, "[:.:]"))
 
     ##*.bin? >> correct to binx
     if(temp.file.name[length(temp.file.name)]=="bin"){
-
       temp.file.name[length(temp.file.name)] <- "binx"
       file <- paste(temp.file.name, collapse=".")
 
@@ -286,7 +281,6 @@ write_R2BIN <- function(
 
   ##enables compatibility to the Analyst as the the max value for POSITION becomes 48
   if(compatibility.mode){
-
     ##just do if position values > 48
     if(max(object@METADATA[,"POSITION"])>48){
 
@@ -315,37 +309,19 @@ write_R2BIN <- function(
 
   }
 
-
   ##COMMENT
   if(max(nchar(as.character(object@METADATA[,"COMMENT"]), type="bytes"))>80){
-
-    stop("[write_R2BIN()] 'COMMENT' exceed storage limit!")
+    stop("[write_R2BIN()] 'COMMENT' exceeds storage limit!", call. = FALSE)
 
   }
 
-
-
-  # Tranlation Matrices -----------------------------------------------------
-
+  # Translation Matrices -----------------------------------------------------
   ##LTYPE
   LTYPE.TranslationMatrix <- matrix(NA, nrow=14, ncol=2)
   LTYPE.TranslationMatrix[,1] <- 0:13
-  LTYPE.TranslationMatrix[,2] <- c("TL",
-                                   "OSL",
-                                   "IRSL",
-                                   "M-IR",
-                                   "M-VIS",
-                                   "TOL",
-                                   "TRPOSL",
-                                   "RIR",
-                                   "RBR",
-                                   "USER",
-                                   "POSL",
-                                   "SGOSL",
-                                   "RL",
-                                   "XRF")
-
-
+  LTYPE.TranslationMatrix[,2] <- c(
+    "TL", "OSL", "IRSL", "M-IR", "M-VIS", "TOL", "TRPOSL", "RIR", "RBR",
+    "USER", "POSL", "SGOSL", "RL", "XRF")
 
   ##DTYPE
   DTYPE.TranslationMatrix <- matrix(NA, nrow=8, ncol=2)
@@ -354,23 +330,15 @@ write_R2BIN <- function(
                                    "Bleach+dose","Natural (Bleach)",
                                    "N+dose (Bleach)","Dose","Background")
 
-
   ##LIGHTSOURCE
   LIGHTSOURCE.TranslationMatrix <- matrix(NA, nrow=8, ncol=2)
   LIGHTSOURCE.TranslationMatrix[,1] <- 0:7
-  LIGHTSOURCE.TranslationMatrix[,2] <- c("None",
-                                         "Lamp",
-                                         "IR diodes/IR Laser",
-                                         "Calibration LED",
-                                         "Blue Diodes",
-                                         "White light",
-                                         "Green laser (single grain)",
-                                         "IR laser (single grain)"
+  LIGHTSOURCE.TranslationMatrix[,2] <- c(
+    "None", "Lamp", "IR diodes/IR Laser", "Calibration LED", "Blue Diodes",
+    "White light", "Green laser (single grain)", "IR laser (single grain)"
   )
 
-
   ##TRANSLATE VALUES IN METADATA
-
   ##LTYPE
   if(is(object@METADATA[1,"LTYPE"], "character") == TRUE |
        is(object@METADATA[1,"LTYPE"], "factor") == TRUE){
@@ -403,11 +371,16 @@ write_R2BIN <- function(
     })}
 
   ##TIME
-  object@METADATA[,"TIME"] <- sapply(1:length(object@METADATA[,"TIME"]),function(x){
+  object@METADATA[,"TIME"] <- vapply(1:length(object@METADATA[["TIME"]]),function(x){
+    if(is.na(object@METADATA[["TIME"]][x])){
+      "000000"
 
-    as.character(gsub(":","",object@METADATA[x,"TIME"]))
+    }else{
+      as.character(gsub(":","",object@METADATA[["TIME"]][x]))
 
-  })
+    }
+
+  }, character(1))
 
   ##TAG and SEL
   ##in TAG information on the SEL are storred, here the values are copied to TAG
@@ -415,29 +388,22 @@ write_R2BIN <- function(
   object@METADATA[,"TAG"] <- ifelse(object@METADATA[,"SEL"] == TRUE, 1, 0)
 
   # SET FILE AND VALUES -----------------------------------------------------
-
   con<-file(file, "wb")
 
   ##get records
   n.records <- length(object@METADATA[,"ID"])
 
   ##output
-  cat(paste("\n[write_R2BIN()]\n\t >> ",file,sep=""), fill=TRUE)
+  message(paste0("[write_R2BIN()]\n\t >> ",file))
 
   ##set progressbar
-  if(txtProgressBar==TRUE){
-    pb<-txtProgressBar(min=0,max=n.records, char="=", style=3)
-  }
-
-
+  if(txtProgressBar)
+    pb <- txtProgressBar(min=0,max=n.records, char="=", style=3)
 
   # LOOP -------------------------------------------------------------------
-
   ID <- 1
-
   if(version == 03 || version == 04){
     ## version 03 and 04
-
     ##start loop for export BIN data
     while(ID<=n.records) {
 
@@ -462,14 +428,12 @@ write_R2BIN <- function(
                size = 2,
                endian="little")
 
-
       ##LTYPE
       writeBin(object@METADATA[ID,"LTYPE"],
                con,
                size = 1,
                endian="little")
 
-
       ##LOW, HIGH, RATE
       writeBin(c(as.double(object@METADATA[ID,"LOW"]),
                  as.double(object@METADATA[ID,"HIGH"]),
@@ -478,7 +442,6 @@ write_R2BIN <- function(
                size = 4,
                endian="little")
 
-
       ##TEMPERATURE, XCOORD, YCOORD, TOLDELAY; TOLON, TOLOFF
       writeBin(c(as.integer(object@METADATA[ID,"TEMPERATURE"]),
                  as.integer(object@METADATA[ID,"XCOORD"]),
@@ -497,8 +460,6 @@ write_R2BIN <- function(
                size = 1,
                endian="little")
 
-
-
       ##TIME
       TIME_SIZE <- nchar(object@METADATA[ID,"TIME"])
       writeBin(as.integer(TIME_SIZE),
@@ -506,7 +467,6 @@ write_R2BIN <- function(
                size = 1,
                endian="little")
 
-
       writeChar(object@METADATA[ID,"TIME"],
                 con,
                 nchars =TIME_SIZE,
@@ -521,26 +481,22 @@ write_R2BIN <- function(
 
       }
 
-
       ##DATE
       writeBin(as.integer(6),
                con,
                size = 1 ,
                endian="little")
 
-
       suppressWarnings(writeChar(as.character(object@METADATA[ID,"DATE"]),
                                  con,
                                  nchars = 6,
                                  useBytes=TRUE,
                                  eos = NULL))
 
-
-
       ##SEQUENCE
-
       ##count number of characters
-      SEQUENCE_SIZE <- as.integer(nchar(as.character(object@METADATA[["SEQUENCE"]][ID]), type = "bytes", keepNA = FALSE))
+      SEQUENCE_SIZE <- as.integer(
+        nchar(as.character(object@METADATA[["SEQUENCE"]][ID]), type = "bytes", keepNA = FALSE))
 
       writeBin(SEQUENCE_SIZE,
                con,
@@ -616,7 +572,6 @@ write_R2BIN <- function(
                size = 1,
                endian="little")
 
-
       ##AN_TEMP, AN_TIME, NORM1, NORM2, NORM2, BG
       writeBin(c(as.double(object@METADATA[ID,"AN_TEMP"]),
                  as.double(object@METADATA[ID,"AN_TIME"]),
@@ -634,8 +589,6 @@ write_R2BIN <- function(
                size = 2,
                endian="little")
 
-
-
       ##SAMPLE
       SAMPLE_SIZE <- as.integer(nchar(as.character(object@METADATA[ID,"SAMPLE"]), type="bytes"))
 
@@ -652,14 +605,12 @@ write_R2BIN <- function(
                size = 1,
                endian="little")
 
-
       writeChar(as.character(object@METADATA[ID,"SAMPLE"]),
                 con,
                 nchars = SAMPLE_SIZE,
                 useBytes=TRUE,
                 eos = NULL)
 
-
       if((20-SAMPLE_SIZE)>0){
         writeBin(raw(length = (20-SAMPLE_SIZE)),
                  con,
@@ -677,7 +628,6 @@ write_R2BIN <- function(
 
       }
 
-
       writeBin(COMMENT_SIZE,
                con,
                size = 1,
@@ -706,14 +656,12 @@ write_R2BIN <- function(
                size = 1,
                endian="little")
 
-
       ##GRAIN
       writeBin(as.integer(object@METADATA[ID,"GRAIN"]),
                con,
                size = 2,
                endian="little")
 
-
       ##LPOWER
       writeBin(as.double(object@METADATA[ID,"LPOWER"]),
                con,
@@ -728,8 +676,6 @@ write_R2BIN <- function(
 
       ##Further distinction needed to fully support format version 03 and 04 separately
       if(version == 03){
-
-
         ##RESERVED 1
         if(length(object@.RESERVED) == 0 || version.original != version){
           writeBin(raw(length=36),
@@ -737,8 +683,7 @@ write_R2BIN <- function(
                    size = 1,
                    endian="little")
         }else{
-
-          writeBin(object@.RESERVED[[ID]][[1]],
+          writeBin(object = object@.RESERVED[[ID]][[1]],
                    con,
                    size = 1,
                    endian="little")
@@ -784,16 +729,13 @@ write_R2BIN <- function(
 
       } else {
         ##version 04
-
-
         ##RESERVED 1
         if(length(object@.RESERVED) == 0 || version.original != version){
           writeBin(raw(length=20),
                    con,
                    size = 1,
                    endian="little")
-        }else{
-
+        } else{
           writeBin(object@.RESERVED[[ID]][[1]],
                    con,
                    size = 1,
@@ -849,17 +791,13 @@ write_R2BIN <- function(
                    size = 1,
                    endian="little")
 
-        }else{
-
+        } else {
           writeBin(object@.RESERVED[[ID]][[2]],
                    con,
                    size = 1,
                    endian="little")
 
         }
-
-
-
       }
       ##DPOINTS
       writeBin(as.integer(unlist(object@DATA[ID])),
@@ -867,24 +805,18 @@ write_R2BIN <- function(
                size = 4,
                endian="little")
 
-
       #SET UNIQUE ID
-      ID<-ID+1
-
+      ID <- ID + 1
       ##update progress bar
-      if(txtProgressBar==TRUE){
-        setTxtProgressBar(pb, ID)
-      }
+      if(txtProgressBar) setTxtProgressBar(pb, ID)
+
     }
   }
   ## ====================================================
-  ## version 06
-
-  if(version == 06 | version == 07 | version == 08){
-
+  ## version > 06
+  if(version == 05 | version == 06 | version == 07 | version == 08){
     ##start loop for export BIN data
     while(ID<=n.records) {
-
       ##VERSION
       writeBin(as.raw(object@METADATA[ID,"VERSION"]),
                con,
@@ -947,7 +879,6 @@ write_R2BIN <- function(
                 useBytes=TRUE,
                 eos = NULL)
 
-
       if((20-SAMPLE_SIZE)>0){
         writeBin(raw(length = (20-SAMPLE_SIZE)),
                  con,
@@ -977,7 +908,6 @@ write_R2BIN <- function(
                 useBytes=TRUE,
                 eos = NULL)
 
-
       if((80-COMMENT_SIZE)>0){
         writeBin(raw(length = c(80-COMMENT_SIZE)),
                  con,
@@ -1067,7 +997,6 @@ write_R2BIN <- function(
 
       }
 
-
       ##DATE
       writeBin(as.integer(6),
                con,
@@ -1196,11 +1125,20 @@ write_R2BIN <- function(
                endian="little")
 
       ##IRR_DOSERATE, IRR_DOSERATEERR
-      writeBin(c(as.double(object@METADATA[ID,"IRR_DOSERATE"]),
-                 as.double(object@METADATA[ID,"IRR_DOSERATEERR"])),
-               con,
-               size = 4,
-               endian="little")
+      if(version == 05){
+        writeBin(as.double(object@METADATA[ID,"IRR_DOSERATE"]),
+                 con,
+                 size = 4,
+                 endian="little")
+
+      }else{
+        writeBin(c(as.double(object@METADATA[ID,"IRR_DOSERATE"]),
+                   as.double(object@METADATA[ID,"IRR_DOSERATEERR"])),
+                 con,
+                 size = 4,
+                 endian="little")
+
+      }
 
       ##TIMESINCEIRR
       writeBin(c(as.integer(object@METADATA[ID,"TIMESINCEIRR"])),
@@ -1264,7 +1202,21 @@ write_R2BIN <- function(
 
 
       ##add version support for V7
-      if(version == 06){
+      if(version == 05){
+        ##RESERVED 2
+        if(length(object@.RESERVED) == 0 || version.original != version){
+          writeBin(raw(length=4),
+                   con,
+                   size = 1,
+                   endian="little")
+        }else{
+          writeBin(object@.RESERVED[[ID]][[2]],
+                   con,
+                   size = 1,
+                   endian="little")
+        }
+
+      }else if(version == 06){
 
         ##RESERVED 2
         if(length(object@.RESERVED) == 0 || version.original != version){
@@ -1273,7 +1225,6 @@ write_R2BIN <- function(
                    size = 1,
                    endian="little")
         }else{
-
           writeBin(object@.RESERVED[[ID]][[2]],
                    con,
                    size = 1,
@@ -1340,7 +1291,6 @@ write_R2BIN <- function(
             endian = "little"
           )
 
-
           ##RESERVED 2
           if(length(object@.RESERVED) == 0 || version.original != version){
             writeBin(raw(length=42),
@@ -1354,27 +1304,20 @@ write_R2BIN <- function(
                      size = 1,
                      endian="little")
           }
-
-
         }
 
-
       }#end if version decision
-
       ##DPOINTS
       writeBin(as.integer(unlist(object@DATA[ID])),
                con,
                size = 4,
                endian="little")
 
-
       #SET UNIQUE ID
       ID <- ID + 1
 
       ##update progress bar
-      if(txtProgressBar==TRUE){
-        setTxtProgressBar(pb, ID)
-      }
+      if(txtProgressBar)  setTxtProgressBar(pb, ID)
 
     }
   }
@@ -1383,9 +1326,9 @@ write_R2BIN <- function(
   close(con)
   #
   # ##close
-  if(txtProgressBar==TRUE){close(pb)}
+  if(txtProgressBar) close(pb)
 
   ##output
-  cat(paste("\t >> ",ID-1,"records have been written successfully!\n\n",paste=""))
+  message(paste0("\t >> ",ID-1,"records have been written successfully!\n\n"))
 
 }
