@@ -1,12 +1,12 @@
-#' Export RLum-objects to CSV
+#' @title Export RLum-objects to CSV
 #'
-#' This function exports [RLum-class]-objects to CSV-files using the R function
+#' @description This function exports [RLum-class]-objects to CSV-files using the R function
 #' [utils::write.table]. All [RLum-class]-objects are supported, but the
 #' export is lossy, i.e. the pure numerical values are exported only. Information
 #' that cannot be coerced to a [data.frame] or a [matrix] are discarded as well as
 #' metadata.
 #'
-#' However, in combination with the implemented import functions, nearly every
+#' @details However, in combination with the implemented import functions, nearly every
 #' supported import data format can be exported to CSV-files, this gives a great
 #' deal of freedom in terms of compatibility with other tools.
 #'
@@ -46,7 +46,7 @@
 #' option `export == FALSE` a list comprising objects of type [data.frame] and [matrix]
 #'
 #'
-#' @section Function version: 0.2.1
+#' @section Function version: 0.2.2
 #'
 #' @author
 #' Sebastian Kreutzer, Geography & Earth Science, Aberystwyth University (United Kingdom)
@@ -85,14 +85,12 @@ write_RLum2CSV <- function(
   ...
 
 ){
-
   # General tests -------------------------------------------------------------------------------
   if(missing(object)){
     stop("[write_RLum2CSV()] input object is missing!", call. = FALSE)
 
   }
 
-
   # Self-call -----------------------------------------------------------------------------------
   ##this option allows to work on a list of RLum-objects
   if(is.list(object) && !is.data.frame(object)){
@@ -101,17 +99,15 @@ write_RLum2CSV <- function(
       path <- rep(list(path), length = length(object))
 
       ##prefix ... create automatic prefix if nothing is provided
-      if(prefix == ""){
-        prefix <- as.list(paste0("[[",1:length(object),"]]_"))
-
-      }else{
-        prefix <- rep(list(prefix), length = length(object))
-
-      }
+      prefix <- as.list(paste0(prefix[1], "[[",1:length(object),"]]_"))
 
       ##export
       export <- rep(list(export), length = length(object))
 
+      ## write list name to object
+      for (i in 1:length(object))
+        attr(object[[i]], "list_name") <- names(object)[i]
+
     ##execute the self-call function
       temp <- lapply(1:length(object), function(x){
         write_RLum2CSV(
@@ -136,9 +132,7 @@ write_RLum2CSV <- function(
   }
 
   # Integrity tests -----------------------------------------------------------------------------
-
   ##check path
-
     ##if NULL condition
     if(export == TRUE && is.null(path)){
       path <- getwd()
@@ -178,7 +172,6 @@ write_RLum2CSV <- function(
       }
 
     } else if (is(object, "RLum.Results")){
-
       ##unlist what ever comes, but do not break structures like matrices, numerics and
       names <- names(object@data)
 
@@ -226,8 +219,9 @@ write_RLum2CSV <- function(
 
   } else if (inherits(object, "data.frame")) {
     object_list <- list(object)
-    names(object_list) <- paste0(strtrim(paste(colnames(object), collapse = ""), 6), "_single_table")
+    if(!is.null(attr(object, "filename"))) filename <- attr(object, "filename") else  filename <- ""
 
+    names(object_list) <- paste0("conv_", attr(object, "list_name"), filename)
 
   }else{
    stop("[write_RLum2CSV()] Object needs to be a member of the object class RLum!", call. = FALSE)
@@ -236,7 +230,6 @@ write_RLum2CSV <- function(
 
   # Export --------------------------------------------------------------------------------------
   if(export){
-
     ##set export settings for write.table
     export_settings.default <- list(
       append = FALSE,
@@ -259,7 +252,7 @@ write_RLum2CSV <- function(
     for(i in 1:length(object_list)){
       utils::write.table(
         x = object_list[[i]],
-        file = paste0(path,"/",prefix, names(object_list)[i],".csv"),
+        file = paste0(path,"/", prefix, names(object_list)[i],".csv"),
         append = export_settings$append,
         quote =  export_settings$quote,
         sep =  export_settings$sep,
@@ -273,7 +266,6 @@ write_RLum2CSV <- function(
 
     }
 
-
   }else{
     return(object_list)
 
