@@ -1,5 +1,3 @@
-context("calc_MaxDose")
-
 data(ExampleData.DeValues, envir = environment())
 temp <- calc_MaxDose(ExampleData.DeValues$CA1,
                      sigmab = 0.2,
@@ -9,13 +7,16 @@ temp <- calc_MaxDose(ExampleData.DeValues$CA1,
 
 test_that("check class and length of output", {
   testthat::skip_on_cran()
-  expect_equal(is(temp), c("RLum.Results", "RLum"))
+  local_edition(3)
+
+  expect_s4_class(temp, "RLum.Results")
   expect_equal(length(temp), 9)
 
 })
 
 test_that("check values from output example", {
   testthat::skip_on_cran()
+  local_edition(3)
 
   results <- get_RLum(temp)
 
